@@ -197,19 +197,22 @@ class EsHelper:
         return result_dict
 
     def sync_format_es_scan(self, bool_must_list=None, param_list=None, route_key="", scroll="5m", size=10000,
-                            is_need_decrypt_oralce=False, limit=None):
+                            is_need_decrypt_oralce=False, limit=0, offset=0, sort_list=None):
         logging.info("扫描开始，条件是{},查询字段是{}".format(json.dumps(bool_must_list), json.dumps(param_list)))
         skip = 0
+        limit = offset + limit
         request_param = {
             "query": {
                 "bool": {
                     "must": bool_must_list
                 }
             }
-            , "size": size,
+            , "size": size
         }
         if param_list:
             request_param["_source"] = {"include": param_list}
+        if sort_list:
+            request_param["sort"] = sort_list
         res = self.pool.es_selector_way(url_func_str=self.pool.format_scroll_url, param_dict={
             "route_key": route_key,
             "scroll": scroll
@@ -244,7 +247,7 @@ class EsHelper:
                 result_list.append(data["_source"])
             if limit and limit <= len(result_list):
                 break
-        return result_list
+        return result_list[offset:offset + limit]
 
     def sync_format_es_group(self, bool_must_list=None, route_key="", aggs=None):
         params = {
