@@ -513,7 +513,7 @@ class Neo4jHelper:
         return await result.consume()
 
     async def execute_write(self, sql):
-        summary = await self.pool.write_transaction(self.sync_write_work, sql)
+        summary = await self.pool.write_transaction(self.write_work, sql)
         res = eval(summary.counters.__repr__())
         await self.pool.close()
         return res
