@@ -14,22 +14,23 @@ from lesscode.web.business_exception import BusinessException
 async def post(path, data=None,
                base_url=tornado.options.options.data_server,
                result_type="json", pack=False, **kwargs):
+    project_name = tornado.options.options.project_name.encode("utf-8")
     flag = kwargs.pop("flag", True)
     if flag:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
                 "Content-Type": "application/json",
-                "Application-Name": tornado.options.options.application_name
+                "Project-Name": project_name
             }})
         else:
-            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+            kwargs["headers"].update({"Project-Name": project_name})
     else:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
-                "Application-Name": tornado.options.options.application_name
+                "Project-Name": project_name
             }})
         else:
-            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+            kwargs["headers"].update({"Project-Name": project_name})
     async with aiohttp.ClientSession() as session:
         flag = kwargs.pop("flag", True)
         if flag:
@@ -66,12 +67,13 @@ async def post(path, data=None,
 
 async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
               **kwargs):
+    project_name = tornado.options.options.project_name.encode("utf-8")
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
-            "Application-Name": tornado.options.options.application_name
+            "Project-Name": project_name
         }})
     else:
-        kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+        kwargs["headers"].update({"Project-Name": project_name})
 
     async with aiohttp.ClientSession() as session:
         async with session.get(base_url + path, params=params, **kwargs) as resp:
@@ -91,14 +93,15 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
 
 
 def sync_get(path, params=None, base_url=None, result_type="json", pack=False, **kwargs):
+    project_name = tornado.options.options.project_name.encode("utf-8")
     if not base_url:
         base_url = tornado.options.options.data_server
-    if not kwargs.get("headers"):
+    if not kwargs.get("headers") and project_name:
         kwargs.update({"headers": {
-            "Application-Name": tornado.options.options.application_name
+            "Project-Name": project_name
         }})
-    else:
-        kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+    elif project_name:
+        kwargs["headers"].update({"Project-Name": project_name})
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
@@ -118,6 +121,7 @@ def sync_get(path, params=None, base_url=None, result_type="json", pack=False, *
 def sync_post(path, data=None,
               base_url=None,
               result_type="json", pack=False, **kwargs):
+    project_name = tornado.options.options.project_name.encode("utf-8")
     if not base_url:
         base_url = tornado.options.options.data_server
     flag = kwargs.pop("flag", True)
@@ -125,18 +129,18 @@ def sync_post(path, data=None,
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
                 "Content-Type": "application/json",
-                "Application-Name": tornado.options.options.application_name
+                "Project-Name": project_name
             }})
         else:
-            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+            kwargs["headers"].update({"Project-Name": project_name})
         res = requests.post(base_url + path, json=data, **kwargs)
     else:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
-                "Application-Name": tornado.options.options.application_name
+                "Project-Name": project_name
             }})
         else:
-            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+            kwargs["headers"].update({"Project-Name": project_name})
         res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
