@@ -13,6 +13,7 @@ import types
 from datetime import datetime
 from decimal import Decimal
 from typing import Optional, Awaitable, Any
+from urllib.parse import unquote
 
 from bson import ObjectId
 from tornado import httputil
@@ -303,9 +304,12 @@ class BaseHandler(RequestHandler):
             if user_info and isinstance(user_info, dict):
                 user = User()
                 for key in user_info:
-                    if key == "roleIds" and user_info[key] and isinstance(user_info[key], str):
-                        user_info[key] = json.loads(user_info[key])
-                    setattr(user, key, user_info[key])
+                    value = user_info.get(key)
+                    if value and isinstance(value, str):
+                        value = unquote(value)
+                    if key == "roleIds" and value and isinstance(value, str):
+                        user_info[key] = json.loads(value)
+                    setattr(user, key, value)
 
                 return user
         return None
