@@ -93,6 +93,9 @@ class StatusCode:
     PARAM_BIND_FAIL = ("A0403", "参数绑定失败")
     PHONE_NUM_NOT_FOUND = ("A0404", "找不到该用户，手机号码有误")
 
+    # A40开头的状态码
+    REQUEST_PATH_NOT_FOUND = ("A4041", "请求地址不存在")
+
     # A05开头的状态码
 
     # B00开头的状态码
