@@ -51,6 +51,7 @@ define("kafka_config", default={}, type=dict, help="kafka配置")
 define("log_es_config", default={}, type=dict, help="同步日志到es的配置")
 define("cache_conn", default="redis_con_1", type=str, help="redis缓存连接")
 define("cache_enable", default=False, type=bool, help="redis缓存开关")
+define("task_list", default=[], type=list, help="任务列表")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -198,6 +199,13 @@ class WebServer:
                                              **options.scheduler_config.get("options", {}))
         options.scheduler.start()
         logging.info('[Scheduler Init]APScheduler has been started')
+        if options.scheduler_config.get("enable") and options.task_list:
+            for task in options.task_list:
+                if isinstance(task, dict):
+                    task_func = task.get("func")
+                    task_kwargs = task.get("kwargs", {})
+                    if task_func:
+                        options.scheduler.add_job(func=task_func, **task_kwargs)
 
     def service_register(self):
         try:
